/*! \file
    \ingroup OPTKING
    \brief Atomic covalent radii in picometers
*/

#ifndef _psi3_bin_optking_bond_lengths_h_
#define _psi3_bin_optking_bond_lengths_h_

namespace psi { namespace optking {

static float radii[55] = {
/* dummy */ 0,
/*H*/  37,  /*HE*/  32,
/*Li*/ 135, /*Be*/  83, /*B*/   80, /*C*/   75, /*N*/   70, /*O*/   65, /*F*/  65, /*Ne*/ 65,
/*Na*/ 155, /*Mg*/ 127, /*Al*/ 117, /*Si*/ 105, /*P*/  102, /*S*/  100, /*Cl*/ 98, /*Ar*/ 96,
/*K */ 195, /*Ca*/ 176,

/*Sc*/ 142, /*Ti*/ 135, /*V */ 122, /*Cr*/ 126, /*Mn*/ 140,
/*Fe*/ 122, /*Co*/ 122, /*Ni*/ 120, /*Cu*/ 139, /*Zn*/ 130,

                        /*Ga*/ 122, /*Ge*/ 120, /*As*/ 117, /*Se*/ 112, /*Br*/ 110, /*Kr*/102,
/*Rb*/ 0.0,
/*Sr*/ 0.0,
/*Y */ 0.0,
/*Zr*/ 0.0,
/*Nb*/ 0.0,
/*Mo*/ 0.0,
/*Tc*/ 0.0,
/*Ru*/ 0.0,
/*Rh*/ 0.0,
/*Pd*/ 0.0,
/*Ag*/ 0.0,
/*Cd*/ 0.0,
/*In*/ 0.0,
/*Sn*/ 0.0,
/*Sb*/ 0.0,
/*Te*/ 0.0,
/*I */ 0.0,
/*Xe*/ 0.0
};

}} /* namespace psi::optking */

#endif
